# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: handoff.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rhandoff.proto\x12\x07handoff\x1a\x1fgoogle/protobuf/timestamp.proto\"\xeb\x01\n\x11HandoffReferences\x12\x36\n\x06topics\x18\x01 \x03(\x0b\x32&.handoff.HandoffReferences.TopicsEntry\x12=\n\nflow_steps\x18\x02 \x03(\x0b\x32).handoff.HandoffReferences.FlowStepsEntry\x1a-\n\x0bTopicsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x30\n\x0e\x46lowStepsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"\xa6\x01\n\tSipConfig\x12\x31\n\x06invite\x18\x01 \x01(\x0b\x32\x1f.handoff.SipInviteHandoffConfigH\x00\x12/\n\x05refer\x18\x02 \x01(\x0b\x32\x1e.handoff.SipReferHandoffConfigH\x00\x12+\n\x03\x62ye\x18\x03 \x01(\x0b\x32\x1c.handoff.SipByeHandoffConfigH\x00\x42\x08\n\x06\x63onfig\"f\n\x16SipInviteHandoffConfig\x12\x14\n\x0cphone_number\x18\x01 \x01(\t\x12\x19\n\x11outbound_endpoint\x18\x02 \x01(\t\x12\x1b\n\x13outbound_encryption\x18\x03 \x01(\t\"-\n\x15SipReferHandoffConfig\x12\x14\n\x0cphone_number\x18\x01 \x01(\t\"\x15\n\x13SipByeHandoffConfig\"1\n\nSipHeaders\x12#\n\x07headers\x18\x01 \x03(\x0b\x32\x12.handoff.SipHeader\"\'\n\tSipHeader\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"4\n\x08Handoffs\x12(\n\x08handoffs\x18\x01 \x03(\x0b\x32\x16.handoff.HandoffConfig\"\x94\x03\n\rHandoffConfig\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\ncreated_by\x18\x04 \x01(\t\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12&\n\nsip_config\x18\x07 \x01(\x0b\x32\x12.handoff.SipConfig\x12(\n\x0bsip_headers\x18\x08 \x01(\x0b\x32\x13.handoff.SipHeaders\x12\x0e\n\x06\x61\x63tive\x18\t \x01(\x08\x12\x17\n\nupdated_by\x18\n \x01(\tH\x00\x88\x01\x01\x12\x33\n\nupdated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01\x88\x01\x01\x12.\n\nreferences\x18\x0c \x01(\x0b\x32\x1a.handoff.HandoffReferences\x12\x12\n\nis_default\x18\r \x01(\x08\x42\r\n\x0b_updated_byB\r\n\x0b_updated_at\"\xd1\x01\n\x0eHandoff_Create\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12&\n\nsip_config\x18\x04 \x01(\x0b\x32\x12.handoff.SipConfig\x12(\n\x0bsip_headers\x18\x05 \x01(\x0b\x32\x13.handoff.SipHeaders\x12\x0e\n\x06\x61\x63tive\x18\x06 \x01(\x08\x12.\n\nreferences\x18\x07 \x01(\x0b\x32\x1a.handoff.HandoffReferences\"\xc1\x02\n\x0eHandoff_Update\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x03 \x01(\tH\x01\x88\x01\x01\x12+\n\nsip_config\x18\x04 \x01(\x0b\x32\x12.handoff.SipConfigH\x02\x88\x01\x01\x12-\n\x0bsip_headers\x18\x05 \x01(\x0b\x32\x13.handoff.SipHeadersH\x03\x88\x01\x01\x12\x13\n\x06\x61\x63tive\x18\x06 \x01(\x08H\x04\x88\x01\x01\x12\x33\n\nreferences\x18\x07 \x01(\x0b\x32\x1a.handoff.HandoffReferencesH\x05\x88\x01\x01\x42\x07\n\x05_nameB\x0e\n\x0c_descriptionB\r\n\x0b_sip_configB\x0e\n\x0c_sip_headersB\t\n\x07_activeB\r\n\x0b_references\" \n\x12Handoff_SetDefault\x12\n\n\x02id\x18\x01 \x01(\t\"\x1c\n\x0eHandoff_Delete\x12\n\n\x02id\x18\x01 \x01(\t\"\x98\x01\n\x1bHandoff_ResetHandoffConfigs\x12+\n\nsip_config\x18\x01 \x01(\x0b\x32\x12.handoff.SipConfigH\x00\x88\x01\x01\x12-\n\x0bsip_headers\x18\x02 \x01(\x0b\x32\x13.handoff.SipHeadersH\x01\x88\x01\x01\x42\r\n\x0b_sip_configB\x0e\n\x0c_sip_headersb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'handoff_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_HANDOFFREFERENCES_TOPICSENTRY']._options = None
  _globals['_HANDOFFREFERENCES_TOPICSENTRY']._serialized_options = b'8\001'
  _globals['_HANDOFFREFERENCES_FLOWSTEPSENTRY']._options = None
  _globals['_HANDOFFREFERENCES_FLOWSTEPSENTRY']._serialized_options = b'8\001'
  _globals['_HANDOFFREFERENCES']._serialized_start=60
  _globals['_HANDOFFREFERENCES']._serialized_end=295
  _globals['_HANDOFFREFERENCES_TOPICSENTRY']._serialized_start=200
  _globals['_HANDOFFREFERENCES_TOPICSENTRY']._serialized_end=245
  _globals['_HANDOFFREFERENCES_FLOWSTEPSENTRY']._serialized_start=247
  _globals['_HANDOFFREFERENCES_FLOWSTEPSENTRY']._serialized_end=295
  _globals['_SIPCONFIG']._serialized_start=298
  _globals['_SIPCONFIG']._serialized_end=464
  _globals['_SIPINVITEHANDOFFCONFIG']._serialized_start=466
  _globals['_SIPINVITEHANDOFFCONFIG']._serialized_end=568
  _globals['_SIPREFERHANDOFFCONFIG']._serialized_start=570
  _globals['_SIPREFERHANDOFFCONFIG']._serialized_end=615
  _globals['_SIPBYEHANDOFFCONFIG']._serialized_start=617
  _globals['_SIPBYEHANDOFFCONFIG']._serialized_end=638
  _globals['_SIPHEADERS']._serialized_start=640
  _globals['_SIPHEADERS']._serialized_end=689
  _globals['_SIPHEADER']._serialized_start=691
  _globals['_SIPHEADER']._serialized_end=730
  _globals['_HANDOFFS']._serialized_start=732
  _globals['_HANDOFFS']._serialized_end=784
  _globals['_HANDOFFCONFIG']._serialized_start=787
  _globals['_HANDOFFCONFIG']._serialized_end=1191
  _globals['_HANDOFF_CREATE']._serialized_start=1194
  _globals['_HANDOFF_CREATE']._serialized_end=1403
  _globals['_HANDOFF_UPDATE']._serialized_start=1406
  _globals['_HANDOFF_UPDATE']._serialized_end=1727
  _globals['_HANDOFF_SETDEFAULT']._serialized_start=1729
  _globals['_HANDOFF_SETDEFAULT']._serialized_end=1761
  _globals['_HANDOFF_DELETE']._serialized_start=1763
  _globals['_HANDOFF_DELETE']._serialized_end=1791
  _globals['_HANDOFF_RESETHANDOFFCONFIGS']._serialized_start=1794
  _globals['_HANDOFF_RESETHANDOFFCONFIGS']._serialized_end=1946
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: integrations.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12integrations.proto\x12\x0cintegrations\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xc7\x01\n\x0cIntegrations\x12Y\n\x19paragon_providers_by_name\x18\x01 \x03(\x0b\x32\x36.integrations.Integrations.ParagonProvidersByNameEntry\x1a\\\n\x1bParagonProvidersByNameEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x1d.integrations.ParagonProvider:\x02\x38\x01\"\xc4\x02\n\x0fParagonProvider\x12\x13\n\x0bprovider_id\x18\x01 \x01(\t\x12\x1b\n\x13\x61vailable_functions\x18\x02 \x03(\t\x12\x0f\n\x07timeout\x18\x03 \x01(\r\x12\x42\n\x10\x65nv_integrations\x18\x04 \x01(\x0b\x32(.integrations.EnvironmentIntegrationRefs\x12O\n\x12integrations_by_id\x18\x05 \x03(\x0b\x32\x33.integrations.ParagonProvider.IntegrationsByIdEntry\x1aY\n\x15IntegrationsByIdEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .integrations.ParagonIntegration:\x02\x38\x01\"P\n\x1a\x45nvironmentIntegrationRefs\x12\x0f\n\x07sandbox\x18\x01 \x01(\t\x12\x13\n\x0bpre_release\x18\x02 \x01(\t\x12\x0c\n\x04live\x18\x03 \x01(\t\"\xff\x01\n\x12ParagonIntegration\x12\x1d\n\x15paragon_connection_id\x18\x01 \x01(\t\x12\x17\n\x0fparagon_user_id\x18\x02 \x01(\t\x12)\n\x08metadata\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x05 \x01(\t\x12.\n\nupdated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\x07 \x01(\t\"\x9e\x01\n\x13Integration_Connect\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x1d\n\x15paragon_connection_id\x18\x02 \x01(\t\x12\x17\n\x0fparagon_user_id\x18\x03 \x01(\t\x12\x12\n\nclient_env\x18\x05 \x01(\t\x12)\n\x08metadata\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\"Y\n\x12Integration_Enable\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x1d\n\x15paragon_connection_id\x18\x02 \x01(\t\x12\x12\n\nclient_env\x18\x03 \x01(\t\"Z\n\x13Integration_Disable\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x1d\n\x15paragon_connection_id\x18\x02 \x01(\t\x12\x12\n\nclient_env\x18\x03 \x01(\t\"L\n\x1bIntegration_UpdateFunctions\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x1b\n\x13\x61vailable_functions\x18\x02 \x03(\t\"I\n\x16Integration_Disconnect\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x1d\n\x15paragon_connection_id\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'integrations_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_INTEGRATIONS_PARAGONPROVIDERSBYNAMEENTRY']._options = None
  _globals['_INTEGRATIONS_PARAGONPROVIDERSBYNAMEENTRY']._serialized_options = b'8\001'
  _globals['_PARAGONPROVIDER_INTEGRATIONSBYIDENTRY']._options = None
  _globals['_PARAGONPROVIDER_INTEGRATIONSBYIDENTRY']._serialized_options = b'8\001'
  _globals['_INTEGRATIONS']._serialized_start=100
  _globals['_INTEGRATIONS']._serialized_end=299
  _globals['_INTEGRATIONS_PARAGONPROVIDERSBYNAMEENTRY']._serialized_start=207
  _globals['_INTEGRATIONS_PARAGONPROVIDERSBYNAMEENTRY']._serialized_end=299
  _globals['_PARAGONPROVIDER']._serialized_start=302
  _globals['_PARAGONPROVIDER']._serialized_end=626
  _globals['_PARAGONPROVIDER_INTEGRATIONSBYIDENTRY']._serialized_start=537
  _globals['_PARAGONPROVIDER_INTEGRATIONSBYIDENTRY']._serialized_end=626
  _globals['_ENVIRONMENTINTEGRATIONREFS']._serialized_start=628
  _globals['_ENVIRONMENTINTEGRATIONREFS']._serialized_end=708
  _globals['_PARAGONINTEGRATION']._serialized_start=711
  _globals['_PARAGONINTEGRATION']._serialized_end=966
  _globals['_INTEGRATION_CONNECT']._serialized_start=969
  _globals['_INTEGRATION_CONNECT']._serialized_end=1127
  _globals['_INTEGRATION_ENABLE']._serialized_start=1129
  _globals['_INTEGRATION_ENABLE']._serialized_end=1218
  _globals['_INTEGRATION_DISABLE']._serialized_start=1220
  _globals['_INTEGRATION_DISABLE']._serialized_end=1310
  _globals['_INTEGRATION_UPDATEFUNCTIONS']._serialized_start=1312
  _globals['_INTEGRATION_UPDATEFUNCTIONS']._serialized_end=1388
  _globals['_INTEGRATION_DISCONNECT']._serialized_start=1390
  _globals['_INTEGRATION_DISCONNECT']._serialized_end=1463
# @@protoc_insertion_point(module_scope)



from poly.handlers.protobuf import handoff_pb2 as _handoff_pb2
from poly.handlers.protobuf import knowledge_base_pb2 as _knowledge_base_pb2
from poly.handlers.protobuf import stop_keywords_pb2 as _stop_keywords_pb2
from poly.handlers.protobuf import sms_pb2 as _sms_pb2
from poly.handlers.protobuf import variant_pb2 as _variant_pb2
from poly.handlers.protobuf import llm_settings_pb2 as _llm_settings_pb2
from poly.handlers.protobuf import content_filter_settings_pb2 as _content_filter_settings_pb2
from poly.handlers.protobuf import asr_settings_pb2 as _asr_settings_pb2
from poly.handlers.protobuf import asr_pb2 as _asr_pb2
from poly.handlers.protobuf import languages_pb2 as _languages_pb2
from poly.handlers.protobuf import flows_pb2 as _flows_pb2
from poly.handlers.protobuf import functions_pb2 as _functions_pb2
from poly.handlers.protobuf import agent_settings_pb2 as _agent_settings_pb2
from poly.handlers.protobuf import transcript_corrections_pb2 as _transcript_corrections_pb2
from poly.handlers.protobuf import experimental_config_pb2 as _experimental_config_pb2
from poly.handlers.protobuf import pronunciations_pb2 as _pronunciations_pb2
from poly.handlers.protobuf import keyphrase_boosting_pb2 as _keyphrase_boosting_pb2
from poly.handlers.protobuf import start_function_pb2 as _start_function_pb2
from poly.handlers.protobuf import end_function_pb2 as _end_function_pb2
from poly.handlers.protobuf import entities_pb2 as _entities_pb2
from poly.handlers.protobuf import voice_pb2 as _voice_pb2
from poly.handlers.protobuf import api_integrations_pb2 as _api_integrations_pb2
from poly.handlers.protobuf import variables_pb2 as _variables_pb2
from poly.handlers.protobuf import translations_pb2 as _translations_pb2
from poly.handlers.protobuf import channels_pb2 as _channels_pb2
from poly.handlers.protobuf import csat_pb2 as _csat_pb2
from poly.handlers.protobuf import integrations_pb2 as _integrations_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Snapshot(_message.Message):
    __slots__ = ("handoffs", "knowledge_base", "sms", "variant_management", "stop_keywords", "llm_settings", "content_filter_settings", "asr_settings", "languages", "flows", "global_functions", "agent_settings", "transcript_corrections", "experimental_config", "pronunciations", "keyphrases_boosting", "start_function", "end_function", "voices", "entities", "asr", "api_integrations", "variables", "translations", "channels", "csat", "integrations")
    HANDOFFS_FIELD_NUMBER: _ClassVar[int]
    KNOWLEDGE_BASE_FIELD_NUMBER: _ClassVar[int]
    SMS_FIELD_NUMBER: _ClassVar[int]
    VARIANT_MANAGEMENT_FIELD_NUMBER: _ClassVar[int]
    STOP_KEYWORDS_FIELD_NUMBER: _ClassVar[int]
    LLM_SETTINGS_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FILTER_SETTINGS_FIELD_NUMBER: _ClassVar[int]
    ASR_SETTINGS_FIELD_NUMBER: _ClassVar[int]
    LANGUAGES_FIELD_NUMBER: _ClassVar[int]
    FLOWS_FIELD_NUMBER: _ClassVar[int]
    GLOBAL_FUNCTIONS_FIELD_NUMBER: _ClassVar[int]
    AGENT_SETTINGS_FIELD_NUMBER: _ClassVar[int]
    TRANSCRIPT_CORRECTIONS_FIELD_NUMBER: _ClassVar[int]
    EXPERIMENTAL_CONFIG_FIELD_NUMBER: _ClassVar[int]
    PRONUNCIATIONS_FIELD_NUMBER: _ClassVar[int]
    KEYPHRASES_BOOSTING_FIELD_NUMBER: _ClassVar[int]
    START_FUNCTION_FIELD_NUMBER: _ClassVar[int]
    END_FUNCTION_FIELD_NUMBER: _ClassVar[int]
    VOICES_FIELD_NUMBER: _ClassVar[int]
    ENTITIES_FIELD_NUMBER: _ClassVar[int]
    ASR_FIELD_NUMBER: _ClassVar[int]
    API_INTEGRATIONS_FIELD_NUMBER: _ClassVar[int]
    VARIABLES_FIELD_NUMBER: _ClassVar[int]
    TRANSLATIONS_FIELD_NUMBER: _ClassVar[int]
    CHANNELS_FIELD_NUMBER: _ClassVar[int]
    CSAT_FIELD_NUMBER: _ClassVar[int]
    INTEGRATIONS_FIELD_NUMBER: _ClassVar[int]
    handoffs: _handoff_pb2.Handoffs
    knowledge_base: _knowledge_base_pb2.KnowledgeBase
    sms: _sms_pb2.SMS
    variant_management: _variant_pb2.VariantManagement
    stop_keywords: _stop_keywords_pb2.StopKeywords
    llm_settings: _llm_settings_pb2.LLMSettings
    content_filter_settings: _content_filter_settings_pb2.ContentFilterSettings
    asr_settings: _asr_settings_pb2.ASRSettings
    languages: _languages_pb2.Languages
    flows: _flows_pb2.Flows
    global_functions: _functions_pb2.Functions
    agent_settings: _agent_settings_pb2.AgentSettings
    transcript_corrections: _transcript_corrections_pb2.TranscriptCorrections
    experimental_config: _experimental_config_pb2.ExperimentalConfig
    pronunciations: _pronunciations_pb2.Pronunciations
    keyphrases_boosting: _keyphrase_boosting_pb2.KeyphrasesBoosting
    start_function: _start_function_pb2.StartFunction
    end_function: _end_function_pb2.EndFunction
    voices: _voice_pb2.Voices
    entities: _entities_pb2.Entities
    asr: _asr_pb2.Asr
    api_integrations: _api_integrations_pb2.ApiIntegrations
    variables: _variables_pb2.Variables
    translations: _translations_pb2.Translations
    channels: _channels_pb2.Channels
    csat: _csat_pb2.CSATConfig
    integrations: _integrations_pb2.Integrations
    def __init__(self, handoffs: _Optional[_Union[_handoff_pb2.Handoffs, _Mapping]] = ..., knowledge_base: _Optional[_Union[_knowledge_base_pb2.KnowledgeBase, _Mapping]] = ..., sms: _Optional[_Union[_sms_pb2.SMS, _Mapping]] = ..., variant_management: _Optional[_Union[_variant_pb2.VariantManagement, _Mapping]] = ..., stop_keywords: _Optional[_Union[_stop_keywords_pb2.StopKeywords, _Mapping]] = ..., llm_settings: _Optional[_Union[_llm_settings_pb2.LLMSettings, _Mapping]] = ..., content_filter_settings: _Optional[_Union[_content_filter_settings_pb2.ContentFilterSettings, _Mapping]] = ..., asr_settings: _Optional[_Union[_asr_settings_pb2.ASRSettings, _Mapping]] = ..., languages: _Optional[_Union[_languages_pb2.Languages, _Mapping]] = ..., flows: _Optional[_Union[_flows_pb2.Flows, _Mapping]] = ..., global_functions: _Optional[_Union[_functions_pb2.Functions, _Mapping]] = ..., agent_settings: _Optional[_Union[_agent_settings_pb2.AgentSettings, _Mapping]] = ..., transcript_corrections: _Optional[_Union[_transcript_corrections_pb2.TranscriptCorrections, _Mapping]] = ..., experimental_config: _Optional[_Union[_experimental_config_pb2.ExperimentalConfig, _Mapping]] = ..., pronunciations: _Optional[_Union[_pronunciations_pb2.Pronunciations, _Mapping]] = ..., keyphrases_boosting: _Optional[_Union[_keyphrase_boosting_pb2.KeyphrasesBoosting, _Mapping]] = ..., start_function: _Optional[_Union[_start_function_pb2.StartFunction, _Mapping]] = ..., end_function: _Optional[_Union[_end_function_pb2.EndFunction, _Mapping]] = ..., voices: _Optional[_Union[_voice_pb2.Voices, _Mapping]] = ..., entities: _Optional[_Union[_entities_pb2.Entities, _Mapping]] = ..., asr: _Optional[_Union[_asr_pb2.Asr, _Mapping]] = ..., api_integrations: _Optional[_Union[_api_integrations_pb2.ApiIntegrations, _Mapping]] = ..., variables: _Optional[_Union[_variables_pb2.Variables, _Mapping]] = ..., translations: _Optional[_Union[_translations_pb2.Translations, _Mapping]] = ..., channels: _Optional[_Union[_channels_pb2.Channels, _Mapping]] = ..., csat: _Optional[_Union[_csat_pb2.CSATConfig, _Mapping]] = ..., integrations: _Optional[_Union[_integrations_pb2.Integrations, _Mapping]] = ...) -> None: ...
